@@ -282,7 +282,7 @@ class CommandServer(threading.Thread):
                     if data:
                         data = json.loads(data.decode("utf-8"))
                         if self.debug:
-                            self.py3_wrapper.log(u"received %s" % data)
+                            self.py3_wrapper.log("received %s" % data)
                         self.command_runner.run_command(data)
                 finally:
                     # Clean up the connection
@@ -465,10 +465,10 @@ def parse_list_or_docstring(options, sps):
     home_path = os.path.expanduser("~")
     xdg_home_path = os.environ.get("XDG_CONFIG_HOME", "{}/.config".format(home_path))
     options.include_paths = [
-        "{}/.i3/py3status/".format(home_path),
-        "{}/.config/i3/py3status/".format(home_path),
+        "{}/py3status/modules".format(xdg_home_path),
         "{}/i3status/py3status".format(xdg_home_path),
         "{}/i3/py3status".format(xdg_home_path),
+        "{}/.i3/py3status".format(home_path),
     ]
     include_paths = []
     for path in options.include_paths:
@@ -541,7 +541,7 @@ def send_command():
         verbose("connecting to %s" % uds)
         try:
             sock.connect(uds)
-        except socket.error:
+        except OSError:
             # this is a stale socket so delete it
             verbose("stale socket deleting")
             try:
